package de.hft.stuttgart.citydoctor2.connect.edge;

/**
 * This class represents the parent class of all exceptions thrown by the native
 * c++ library for the check- and healkernel for the project CityDoctor. An
 * additionally sting field has been added to identify the thrown Exception, if
 * not a specialized exception has been caught. This keeps the code clearly
 * arranged, because most of the exception that will be thrown represents an
 * severe error in C++, so there it doesn't makes sense to carry on with the
 * java program
 * 
 * @author wewetzer
 * @version 1.0
 */
public abstract class NativeException extends RuntimeException {
	private static final long serialVersionUID = 443321035265866910L;
	String exceptionType = "not specified";

	/**
	 * Standard constructor.
	 */
	public NativeException() {
		super("Message not specified");
	}

	/**
	 * Constructs a NativeException with the given message an the given type
	 * 
	 * @param message The message of the exception
	 */
	public NativeException(String message) {
		super(message);
	}

	/**
	 * Returns the type of the exception
	 * 
	 * @return The type of the exception
	 */
	public String getType() {
		return exceptionType;
	}

}
