package de.hft.stuttgart.citydoctor2.webservice.model.entities;

import java.util.ArrayList;
import java.util.List;

import javax.persistence.Access;
import javax.persistence.AccessType;
import javax.persistence.Basic;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.OneToMany;
import javax.persistence.Table;
import javax.validation.constraints.NotNull;

import org.hibernate.search.annotations.Field;
import org.hibernate.search.annotations.Indexed;

@Entity
@Table(name = "building_reference")
@Indexed
public class WebBuilding {

	@Id
	@GeneratedValue(strategy = GenerationType.IDENTITY)
	@Access(AccessType.PROPERTY)
	private int id;

	@JoinColumn(name = "model_id")
	@NotNull
	@ManyToOne
	private WebCityDoctorModel model;

	@Column(name = "gml_id")
	@NotNull
	@Field
	private String gmlId;
	
	@Column(name = "model_width")
	private double modelWidth;

	@Column(name = "view_data")
	@Basic(fetch = FetchType.LAZY)
	private byte[] viewData;
	
	@OneToMany(mappedBy = "building", orphanRemoval = true)
	private List<WebError> errors = new ArrayList<>();
	
	@OneToMany(mappedBy = "feature", orphanRemoval = true)
	private List<FeatureValidationStatus> errorStatus = new ArrayList<>();

	public List<WebError> getErrors() {
		return errors;
	}

	public void setErrors(List<WebError> errors) {
		this.errors = errors;
	}

	public double getModelWidth() {
		return modelWidth;
	}

	public void setModelWidth(double modelWidth) {
		this.modelWidth = modelWidth;
	}

	public List<FeatureValidationStatus> getErrorStatus() {
		return errorStatus;
	}

	public void setErrorStatus(List<FeatureValidationStatus> errorStatus) {
		this.errorStatus = errorStatus;
	}

	public byte[] getViewData() {
		return viewData;
	}

	public void setViewData(byte[] viewData) {
		this.viewData = viewData;
	}

	public WebCityDoctorModel getModel() {
		return model;
	}

	public void setModel(WebCityDoctorModel model) {
		this.model = model;
	}

	public int getId() {
		return id;
	}

	public void setId(int id) {
		this.id = id;
	}

	public String getGmlId() {
		return gmlId;
	}

	public void setGmlId(String gmlId) {
		this.gmlId = gmlId;
	}
}
